@@ -12,24 +12,24 @@
 #' @param k An integer value indicating the boundary of the division \eqn{(N/k)}.
 #'          The smallest value of \eqn{k} is \eqn{4}.
 #'
-#' @param npoints The number of different window sizes that will be used to estimate the Fluctuation function in each zone. See nonlinearTseries package.
+#' @param npoints The number of different time scales that will be used to estimate the Fluctuation function in each zone. See nonlinearTseries package.
 #'
 #' @return A list contaning "w", "alpha_dfa", "se_alpha_dfa", "r2_alpha_dfa".
 #'
 #' @examples
 #' y <- rnorm(100)
-#' dfa_SlidingWindows(y,w=99,k=10,npoints=15)
+#' dfa.SlidingWindows(y,w=99,k=10,npoints=15)
 #'
 #' @references
-#' GUEDES, E.F.;FERREIRA, P.;DIONISIO, A.; ZEBENDE,G.F. An econophysics approach to study the effect of BREXIT referendum on European Union stock markets. PHYSICA A, v.523, p.1175-1182, 2019. doi = "https://doi.org/10.1016/j.physa.2019.04.132".
+#' GUEDES, E.F.;FERREIRA, P.;DIONISIO, A.; ZEBENDE,G.F. An econophysics approach to study the effect of BREXIT referendum on European Union stock markets. PHYSICA A, v.523, p.1175-1182, 2019. doi = "doi.org/10.1016/j.physa.2019.04.132".
 #'
-#' FERREIRA, P.; DIONISIO, A.;GUEDES, E.F.; ZEBENDE, G.F. A sliding windows approach to analyse the evolution of bank shares in the European Union. PHYSICA A, v.490, p.1355-1367, 2018. doi = "https://doi.org/10.1016/j.physa.2017.08.095".
+#' FERREIRA, P.; DIONISIO, A.;GUEDES, E.F.; ZEBENDE, G.F. A sliding windows approach to analyse the evolution of bank shares in the European Union. PHYSICA A, v.490, p.1355-1367, 2018. doi = "doi.org/10.1016/j.physa.2017.08.095".
 #'
 #' @importFrom nonlinearTseries dfa
 #' @importFrom stats coef lm
 #'
 #' @export
-dfa_SlidingWindows <- function(y,w,k,npoints){
+dfa.SlidingWindows <- function(y,w=98,k=10,npoints=15){
   if(!(is.null(y) || is.numeric(y) || is.logical(y))){
    stop("Time series must be numeric")
    }
